@@ -9,6 +9,40 @@
 
 
 
+---------------------------------------------------------------------
+-- Core types to access the PAGC address standardizer
+-- Author: Stephen Woodbridge <woodbri@imaptools.com>
+---------------------------------------------------------------------
+
+CREATE TYPE stdaddr AS (
+    building text,
+    house_num text,
+    predir text,
+    qual text,
+    pretype text,
+    name text,
+    suftype text,
+    sufdir text,
+    ruralroute text,
+    extra text,
+    city text,
+    state text,
+    country text,
+    postcode text,
+    box text,
+    unit text
+);
+
+
+
+
+
+
+
+
+
+
+
 ---------------------------------------------------------------------
 -- Core function to access the PAGC address standardizer
 -- Author: Stephen Woodbridge <woodbri@imaptools.com>
@@ -21,7 +55,7 @@ CREATE OR REPLACE FUNCTION standardize_address(
         micro text,
         macro text )
     RETURNS stdaddr
-    AS  '$libdir/address_standardizer', 'standardize_address'
+    AS  '$libdir/address_standardizer-3', 'standardize_address'
     LANGUAGE 'c' IMMUTABLE STRICT COST 200;
 
 CREATE OR REPLACE FUNCTION standardize_address(
@@ -30,7 +64,7 @@ CREATE OR REPLACE FUNCTION standardize_address(
         rultab text,
         address text )
     RETURNS stdaddr
-    AS  '$libdir/address_standardizer', 'standardize_address1'
+    AS  '$libdir/address_standardizer-3', 'standardize_address1'
     LANGUAGE 'c' IMMUTABLE STRICT COST 200;
 
 CREATE OR REPLACE FUNCTION parse_address(IN text,
@@ -44,6 +78,6 @@ CREATE OR REPLACE FUNCTION parse_address(IN text,
         OUT zipplus text,
         OUT country text)
     RETURNS record
-    AS  '$libdir/address_standardizer', 'parse_address'
+    AS  '$libdir/address_standardizer-3', 'parse_address'
     LANGUAGE 'c' IMMUTABLE STRICT;
 
